@@ -103,7 +103,7 @@ VALIDATE_TASK_SCHEMA = '''{
                         "type": "object"
                     },
                     "reward": {
-                        "default": 1000,
+                        "default": 1000.1,
                         "format": "double",
                         "maximum": 1000000,
                         "minimum": 0,
@@ -329,7 +329,7 @@ VALIDATE_TASK_SCHEMA = '''{
                                                             "type": "object"
                                                         },
                                                         "reward": {
-                                                            "default": 1000,
+                                                            "default": 1000.1,
                                                             "format": "double",
                                                             "maximum": 1000000,
                                                             "minimum": 0,
@@ -517,7 +517,7 @@ VALIDATE_TASK_SCHEMA = '''{
                                                             "type": "object"
                                                         },
                                                         "reward": {
-                                                            "default": 1000,
+                                                            "default": 1000.1,
                                                             "format": "double",
                                                             "maximum": 1000000,
                                                             "minimum": 0,
@@ -900,6 +900,42 @@ VALIDATE_TASK_SCHEMA = '''{
                     "minLength": 1,
                     "type": "string"
                 },
+                "penalties": {
+                    "additionalProperties": false,
+                    "nullable": false,
+                    "properties": {
+                        "compatibilities": {
+                            "default": [],
+                            "items": {
+                                "additionalProperties": false,
+                                "nullable": false,
+                                "properties": {
+                                    "penalty": {
+                                        "default": 0,
+                                        "format": "double",
+                                        "maximum": 1000000,
+                                        "minimum": 0,
+                                        "type": "number"
+                                    },
+                                    "tag": {
+                                        "maxLength": 256,
+                                        "minLength": 1,
+                                        "type": "string"
+                                    }
+                                },
+                                "required": [
+                                    "tag",
+                                    "penalty"
+                                ],
+                                "type": "object"
+                            },
+                            "maxItems": 1000000,
+                            "minItems": 0,
+                            "type": "array"
+                        }
+                    },
+                    "type": "object"
+                },
                 "planning_time": {
                     "default": 20,
                     "format": "int32",
@@ -1149,6 +1185,14 @@ VALIDATE_TASK_SCHEMA = '''{
                     "maxItems": 7,
                     "minItems": 0,
                     "type": "array"
+                },
+                "trip_start_time_strategy": {
+                    "default": "EARLIEST_FINISH",
+                    "enum": [
+                        "EARLIEST_FINISH",
+                        "LOWEST_COST"
+                    ],
+                    "type": "string"
                 }
             },
             "type": "object"
